==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/d03/station__widget_8h.js <==
var station__widget_8h =
[
    [ "JoinStationWidgets", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2", [
      [ "WID_JS_CAPTION", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a1a726db90274f4c0789b00dcd4e0f44d", null ],
      [ "WID_JS_PANEL", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a51416e7156e32a6f418dccaea46bbe70", null ],
      [ "WID_JS_SCROLLBAR", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a57655070ab3fe260d1eb56a2ff0a24c5", null ]
    ] ],
    [ "StationListWidgets", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7", [
      [ "WID_STL_CAPTION", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a17b10c06d3291f3dd82b70138f1b766a", null ],
      [ "WID_STL_LIST", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7acba7911e3535e84fb33c53a5860fa241", null ],
      [ "WID_STL_SCROLLBAR", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a3d15a87f47353feb4a9ea6a2dab6aaf1", null ],
      [ "WID_STL_TRAIN", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a9d7f740f8036d5855e6502f6e9210c6b", null ],
      [ "WID_STL_TRUCK", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a1e8dac35b1fbc39b796961049ae99a03", null ],
      [ "WID_STL_BUS", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aafaf6c77540765397f2a5dc84d5aa162", null ],
      [ "WID_STL_AIRPLANE", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aedd6bf03f6bebe3ac8b7d0276424cbb9", null ],
      [ "WID_STL_SHIP", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7acd7a57824798a77afcb4054220dde8ce", null ],
      [ "WID_STL_FACILALL", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7abeb2ce390c52feb92283f55c3dce598f", null ],
      [ "WID_STL_NOCARGOWAITING", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aeba3bb41ad4a0a9e3c139a46d72eb0d8", null ],
      [ "WID_STL_CARGOALL", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a1e18a0163dc2439888787d03ce135ea2", null ],
      [ "WID_STL_SORTBY", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a938c71d6fdcbc3feb0dbae44c3fd9842", null ],
      [ "WID_STL_SORTDROPBTN", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a89c2389f637489da526d78f1082a338d", null ],
      [ "WID_STL_CARGOSTART", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a6e748864631d4f3a8cc57236b5256ca8", null ]
    ] ],
    [ "StationViewWidgets", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2e", [
      [ "WID_SV_CAPTION", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea575ceb9bf1c27c9e06b787a7accff3ee", null ],
      [ "WID_SV_SORT_ORDER", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea349ee727e6d454a10abf777a4ec10c75", null ],
      [ "WID_SV_SORT_BY", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea8e75448bcbdd66be62b9db883a5e67f0", null ],
      [ "WID_SV_GROUP", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea646db613f68ab7414b4718e2bc02eef9", null ],
      [ "WID_SV_GROUP_BY", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea967cd9a8470ac3a5066ccfc1a4fb6c3d", null ],
      [ "WID_SV_WAITING", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eab376cb9467939872957ea603cdf928c2", null ],
      [ "WID_SV_SCROLLBAR", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea4a52e33764d3c0cc972061e2bb94cb2b", null ],
      [ "WID_SV_ACCEPT_RATING_LIST", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eaa12e6d4a0264c8c51a85ea1ba27646e6", null ],
      [ "WID_SV_LOCATION", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eac57017937d828f277b3f9416cba5538e", null ],
      [ "WID_SV_ACCEPTS_RATINGS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eae1cf95df22684d4e8d0a5b1ea2eeed45", null ],
      [ "WID_SV_RENAME", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea7d25d03d58a7d54b7a57a764c3de549b", null ],
      [ "WID_SV_CLOSE_AIRPORT", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea1282b8451ad484745d12fcf78b376c60", null ],
      [ "WID_SV_TRAINS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ead3248abc89a5b9ad2e4bf2645eed5eb8", null ],
      [ "WID_SV_ROADVEHS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea44ade88d0807ba1df47737081ada63ee", null ],
      [ "WID_SV_SHIPS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eab8a7a19bfb9751baa900b95b3e906ed3", null ],
      [ "WID_SV_PLANES", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eaa05a626b1bb24bc60a1304245faf1e13", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/d03/station__widget_8h.js <==
var station__widget_8h =
[
    [ "JoinStationWidgets", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2", [
      [ "WID_JS_CAPTION", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a1a726db90274f4c0789b00dcd4e0f44d", null ],
      [ "WID_JS_PANEL", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a51416e7156e32a6f418dccaea46bbe70", null ],
      [ "WID_JS_SCROLLBAR", "d2/d03/station__widget_8h.html#acba92abe4983de7b8e842ddc089ea1d2a57655070ab3fe260d1eb56a2ff0a24c5", null ]
    ] ],
    [ "StationListWidgets", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7", [
      [ "WID_STL_CAPTION", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a17b10c06d3291f3dd82b70138f1b766a", null ],
      [ "WID_STL_LIST", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7acba7911e3535e84fb33c53a5860fa241", null ],
      [ "WID_STL_SCROLLBAR", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a3d15a87f47353feb4a9ea6a2dab6aaf1", null ],
      [ "WID_STL_TRAIN", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a9d7f740f8036d5855e6502f6e9210c6b", null ],
      [ "WID_STL_TRUCK", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a1e8dac35b1fbc39b796961049ae99a03", null ],
      [ "WID_STL_BUS", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aafaf6c77540765397f2a5dc84d5aa162", null ],
      [ "WID_STL_AIRPLANE", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aedd6bf03f6bebe3ac8b7d0276424cbb9", null ],
      [ "WID_STL_SHIP", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7acd7a57824798a77afcb4054220dde8ce", null ],
      [ "WID_STL_FACILALL", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7abeb2ce390c52feb92283f55c3dce598f", null ],
      [ "WID_STL_NOCARGOWAITING", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7aeba3bb41ad4a0a9e3c139a46d72eb0d8", null ],
      [ "WID_STL_CARGOALL", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a1e18a0163dc2439888787d03ce135ea2", null ],
      [ "WID_STL_SORTBY", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a938c71d6fdcbc3feb0dbae44c3fd9842", null ],
      [ "WID_STL_SORTDROPBTN", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a89c2389f637489da526d78f1082a338d", null ],
      [ "WID_STL_CARGOSTART", "d2/d03/station__widget_8h.html#a362532d6b613e9fb19aebe5779e0bdc7a6e748864631d4f3a8cc57236b5256ca8", null ]
    ] ],
    [ "StationViewWidgets", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2e", [
      [ "WID_SV_CAPTION", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea575ceb9bf1c27c9e06b787a7accff3ee", null ],
      [ "WID_SV_GROUP", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea646db613f68ab7414b4718e2bc02eef9", null ],
      [ "WID_SV_GROUP_BY", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea967cd9a8470ac3a5066ccfc1a4fb6c3d", null ],
      [ "WID_SV_SORT_ORDER", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea349ee727e6d454a10abf777a4ec10c75", null ],
      [ "WID_SV_SORT_BY", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea8e75448bcbdd66be62b9db883a5e67f0", null ],
      [ "WID_SV_WAITING", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eab376cb9467939872957ea603cdf928c2", null ],
      [ "WID_SV_SCROLLBAR", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea4a52e33764d3c0cc972061e2bb94cb2b", null ],
      [ "WID_SV_ACCEPT_RATING_LIST", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eaa12e6d4a0264c8c51a85ea1ba27646e6", null ],
      [ "WID_SV_LOCATION", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eac57017937d828f277b3f9416cba5538e", null ],
      [ "WID_SV_ACCEPTS_RATINGS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eae1cf95df22684d4e8d0a5b1ea2eeed45", null ],
      [ "WID_SV_RENAME", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea7d25d03d58a7d54b7a57a764c3de549b", null ],
      [ "WID_SV_CLOSE_AIRPORT", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea1282b8451ad484745d12fcf78b376c60", null ],
      [ "WID_SV_TRAINS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ead3248abc89a5b9ad2e4bf2645eed5eb8", null ],
      [ "WID_SV_ROADVEHS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea44ade88d0807ba1df47737081ada63ee", null ],
      [ "WID_SV_SHIPS", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eab8a7a19bfb9751baa900b95b3e906ed3", null ],
      [ "WID_SV_PLANES", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2eaa05a626b1bb24bc60a1304245faf1e13", null ],
      [ "WID_SV_CATCHMENT", "d2/d03/station__widget_8h.html#a4d2e3bf389cab1ed745e5dd4c16c4a2ea4218b8725f84355e21f34a7face343f5", null ]
    ] ]
];
